==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPivotDimensionStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionStrategyDescription } from "./WebPivotDimensionStrategyDescription";
/**
 * @hidden
 */
var WebPivotDimensionStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionStrategyDescriptionMetadata, _super);
    function WebPivotDimensionStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionStrategyDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionStrategyDescriptionMetadata.a == null) {
            WebPivotDimensionStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionStrategyDescriptionMetadata.c(WebPivotDimensionStrategyDescriptionMetadata.a);
        }
        if (a.j(WebPivotDimensionStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPivotDimensionStrategyDescriptionMetadata.a);
    };
    WebPivotDimensionStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebPivotDimensionStrategyDescriptionMetadata.d = function (a) {
        WebPivotDimensionStrategyDescriptionMetadata.b(a);
        a.aa("WebPivotDimensionStrategy", function () { return new WebPivotDimensionStrategyDescription(); });
        a.z("WebPivotDimensionStrategy", WebPivotDimensionStrategyDescriptionMetadata.a);
    };
    WebPivotDimensionStrategyDescriptionMetadata.$t = markType(WebPivotDimensionStrategyDescriptionMetadata, 'WebPivotDimensionStrategyDescriptionMetadata');
    WebPivotDimensionStrategyDescriptionMetadata.a = null;
    return WebPivotDimensionStrategyDescriptionMetadata;
}(Base));
export { WebPivotDimensionStrategyDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPivotDimensionStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionStrategyDescription } from "./WebPivotDimensionStrategyDescription";
/**
 * @hidden
 */
var WebPivotDimensionStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotDimensionStrategyDescriptionMetadata, _super);
    function WebPivotDimensionStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotDimensionStrategyDescriptionMetadata.b = function (a) {
        if (WebPivotDimensionStrategyDescriptionMetadata.a == null) {
            WebPivotDimensionStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotDimensionStrategyDescriptionMetadata.c(WebPivotDimensionStrategyDescriptionMetadata.a);
        }
        if (a.k(WebPivotDimensionStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPivotDimensionStrategyDescriptionMetadata.a);
    };
    WebPivotDimensionStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotDimensionStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebPivotDimensionStrategyDescriptionMetadata.d = function (a) {
        WebPivotDimensionStrategyDescriptionMetadata.b(a);
        a.ac("WebPivotDimensionStrategy", function () { return new WebPivotDimensionStrategyDescription(); });
        a.ab("WebPivotDimensionStrategy", WebPivotDimensionStrategyDescriptionMetadata.a);
    };
    WebPivotDimensionStrategyDescriptionMetadata.$t = markType(WebPivotDimensionStrategyDescriptionMetadata, 'WebPivotDimensionStrategyDescriptionMetadata');
    WebPivotDimensionStrategyDescriptionMetadata.a = null;
    return WebPivotDimensionStrategyDescriptionMetadata;
}(Base));
export { WebPivotDimensionStrategyDescriptionMetadata };
